# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SET_MAP_NAMES_METADATA = Metadata(
    id="7f2099c8418ca1e3fe54b4ccfa0b3990d98a392d.boutiques",
    name="set-map-names",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SetMapNamesMapParameters = typing.TypedDict('SetMapNamesMapParameters', {
    "@type": typing.NotRequired[typing.Literal["map"]],
    "index": int,
    "new_name": str,
})
SetMapNamesMapParametersTagged = typing.TypedDict('SetMapNamesMapParametersTagged', {
    "@type": typing.Literal["map"],
    "index": int,
    "new_name": str,
})


SetMapNamesParameters = typing.TypedDict('SetMapNamesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/set-map-names"]],
    "data_file": str,
    "opt_name_file_file": typing.NotRequired[str | None],
    "opt_from_data_file_file": typing.NotRequired[str | None],
    "map": typing.NotRequired[list[SetMapNamesMapParameters] | None],
})
SetMapNamesParametersTagged = typing.TypedDict('SetMapNamesParametersTagged', {
    "@type": typing.Literal["workbench/set-map-names"],
    "data_file": str,
    "opt_name_file_file": typing.NotRequired[str | None],
    "opt_from_data_file_file": typing.NotRequired[str | None],
    "map": typing.NotRequired[list[SetMapNamesMapParameters] | None],
})


def set_map_names_map_params(
    index: int,
    new_name: str,
) -> SetMapNamesMapParametersTagged:
    """
    Build parameters.
    
    Args:
        index: the map index to change the name of.
        new_name: the name to set for the map.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "map",
        "index": index,
        "new_name": new_name,
    }
    return params


def set_map_names_map_cargs(
    params: SetMapNamesMapParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-map")
    cargs.append(str(params.get("index", None)))
    cargs.append(params.get("new_name", None))
    return cargs


class SetMapNamesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SetMapNamesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def set_map_names_params(
    data_file: str,
    opt_name_file_file: str | None = None,
    opt_from_data_file_file: str | None = None,
    map_: list[SetMapNamesMapParameters] | None = None,
) -> SetMapNamesParametersTagged:
    """
    Build parameters.
    
    Args:
        data_file: the file to set the map names of.
        opt_name_file_file: use a text file to replace all map names: text file\
            containing map names, one per line.
        opt_from_data_file_file: use the map names from another data file: a\
            data file with the same number of maps.
        map_: specify a map to set the name of.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/set-map-names",
        "data_file": data_file,
    }
    if opt_name_file_file is not None:
        params["opt_name_file_file"] = opt_name_file_file
    if opt_from_data_file_file is not None:
        params["opt_from_data_file_file"] = opt_from_data_file_file
    if map_ is not None:
        params["map"] = map_
    return params


def set_map_names_cargs(
    params: SetMapNamesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-set-map-names")
    cargs.append(params.get("data_file", None))
    if params.get("opt_name_file_file", None) is not None:
        cargs.extend([
            "-name-file",
            params.get("opt_name_file_file", None)
        ])
    if params.get("opt_from_data_file_file", None) is not None:
        cargs.extend([
            "-from-data-file",
            params.get("opt_from_data_file_file", None)
        ])
    if params.get("map", None) is not None:
        cargs.extend([a for c in [set_map_names_map_cargs(s, execution) for s in params.get("map", None)] for a in c])
    return cargs


def set_map_names_outputs(
    params: SetMapNamesParameters,
    execution: Execution,
) -> SetMapNamesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SetMapNamesOutputs(
        root=execution.output_file("."),
    )
    return ret


def set_map_names_execute(
    params: SetMapNamesParameters,
    runner: Runner | None = None,
) -> SetMapNamesOutputs:
    """
    set-map-names
    
    Set the name of one or more maps in a file.
    
    Sets the name of one or more maps for metric, shape, label, volume, cifti
    scalar or cifti label files. You must specify either -name-file, or
    -from-data-file, or at least one -map option. The three option types are
    mutually exclusive.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetMapNamesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_MAP_NAMES_METADATA)
    params = execution.params(params)
    cargs = set_map_names_cargs(params, execution)
    ret = set_map_names_outputs(params, execution)
    execution.run(cargs)
    return ret


def set_map_names(
    data_file: str,
    opt_name_file_file: str | None = None,
    opt_from_data_file_file: str | None = None,
    map_: list[SetMapNamesMapParameters] | None = None,
    runner: Runner | None = None,
) -> SetMapNamesOutputs:
    """
    set-map-names
    
    Set the name of one or more maps in a file.
    
    Sets the name of one or more maps for metric, shape, label, volume, cifti
    scalar or cifti label files. You must specify either -name-file, or
    -from-data-file, or at least one -map option. The three option types are
    mutually exclusive.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_file: the file to set the map names of.
        opt_name_file_file: use a text file to replace all map names: text file\
            containing map names, one per line.
        opt_from_data_file_file: use the map names from another data file: a\
            data file with the same number of maps.
        map_: specify a map to set the name of.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetMapNamesOutputs`).
    """
    params = set_map_names_params(
        data_file=data_file,
        opt_name_file_file=opt_name_file_file,
        opt_from_data_file_file=opt_from_data_file_file,
        map_=map_,
    )
    return set_map_names_execute(params, runner)


__all__ = [
    "SET_MAP_NAMES_METADATA",
    "SetMapNamesOutputs",
    "set_map_names",
    "set_map_names_execute",
    "set_map_names_map_params",
    "set_map_names_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_REORIENT_METADATA = Metadata(
    id="993d128d1b8587b85bf89235de06096fbfc8baea.boutiques",
    name="volume-reorient",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeReorientParameters = typing.TypedDict('VolumeReorientParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-reorient"]],
    "volume": InputPathType,
    "orient_string": str,
    "volume_out": str,
})
VolumeReorientParametersTagged = typing.TypedDict('VolumeReorientParametersTagged', {
    "@type": typing.Literal["workbench/volume-reorient"],
    "volume": InputPathType,
    "orient_string": str,
    "volume_out": str,
})


class VolumeReorientOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeReorientParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_reorient_params(
    volume: InputPathType,
    orient_string: str,
    volume_out: str,
) -> VolumeReorientParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the volume to reorient.
        orient_string: the desired orientation.
        volume_out: out - the reoriented volume.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-reorient",
        "volume": volume,
        "orient_string": orient_string,
        "volume_out": volume_out,
    }
    return params


def volume_reorient_cargs(
    params: VolumeReorientParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-reorient")
    cargs.append(execution.input_file(params.get("volume", None)))
    cargs.append(params.get("orient_string", None))
    cargs.append(params.get("volume_out", None))
    return cargs


def volume_reorient_outputs(
    params: VolumeReorientParameters,
    execution: Execution,
) -> VolumeReorientOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeReorientOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_reorient_execute(
    params: VolumeReorientParameters,
    runner: Runner | None = None,
) -> VolumeReorientOutputs:
    """
    volume-reorient
    
    Change voxel order of a volume file.
    
    Changes the voxel order and the header spacing/origin information such that
    the value of any spatial point is unchanged. Orientation strings look like
    'LPI', which means first index is left to right, second is posterior to
    anterior, and third is inferior to superior. The valid characters are:
    
    L left to right
    R right to left
    P posterior to anterior
    A anterior to posterior
    I inferior to superior
    S superior to inferior.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeReorientOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_REORIENT_METADATA)
    params = execution.params(params)
    cargs = volume_reorient_cargs(params, execution)
    ret = volume_reorient_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_reorient(
    volume: InputPathType,
    orient_string: str,
    volume_out: str,
    runner: Runner | None = None,
) -> VolumeReorientOutputs:
    """
    volume-reorient
    
    Change voxel order of a volume file.
    
    Changes the voxel order and the header spacing/origin information such that
    the value of any spatial point is unchanged. Orientation strings look like
    'LPI', which means first index is left to right, second is posterior to
    anterior, and third is inferior to superior. The valid characters are:
    
    L left to right
    R right to left
    P posterior to anterior
    A anterior to posterior
    I inferior to superior
    S superior to inferior.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume to reorient.
        orient_string: the desired orientation.
        volume_out: out - the reoriented volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeReorientOutputs`).
    """
    params = volume_reorient_params(
        volume=volume,
        orient_string=orient_string,
        volume_out=volume_out,
    )
    return volume_reorient_execute(params, runner)


__all__ = [
    "VOLUME_REORIENT_METADATA",
    "VolumeReorientOutputs",
    "volume_reorient",
    "volume_reorient_execute",
    "volume_reorient_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_EXPORT_TABLE_METADATA = Metadata(
    id="a31add98256d4ff82cd9abbe5312eef2ca2e6451.boutiques",
    name="cifti-label-export-table",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelExportTableParameters = typing.TypedDict('CiftiLabelExportTableParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-export-table"]],
    "label_in": InputPathType,
    "map": str,
    "table_out": str,
})
CiftiLabelExportTableParametersTagged = typing.TypedDict('CiftiLabelExportTableParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-export-table"],
    "label_in": InputPathType,
    "map": str,
    "table_out": str,
})


class CiftiLabelExportTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelExportTableParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_label_export_table_params(
    label_in: InputPathType,
    map_: str,
    table_out: str,
) -> CiftiLabelExportTableParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input cifti label file.
        map_: the number or name of the label map to use.
        table_out: output - the output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-export-table",
        "label_in": label_in,
        "map": map_,
        "table_out": table_out,
    }
    return params


def cifti_label_export_table_cargs(
    params: CiftiLabelExportTableParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-export-table")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("map", None))
    cargs.append(params.get("table_out", None))
    return cargs


def cifti_label_export_table_outputs(
    params: CiftiLabelExportTableParameters,
    execution: Execution,
) -> CiftiLabelExportTableOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelExportTableOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_label_export_table_execute(
    params: CiftiLabelExportTableParameters,
    runner: Runner | None = None,
) -> CiftiLabelExportTableOutputs:
    """
    cifti-label-export-table
    
    Export label table from cifti as text.
    
    Takes the label table from the cifti label map, and writes it to a text
    format matching what is expected by -cifti-label-import.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelExportTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_EXPORT_TABLE_METADATA)
    params = execution.params(params)
    cargs = cifti_label_export_table_cargs(params, execution)
    ret = cifti_label_export_table_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_export_table(
    label_in: InputPathType,
    map_: str,
    table_out: str,
    runner: Runner | None = None,
) -> CiftiLabelExportTableOutputs:
    """
    cifti-label-export-table
    
    Export label table from cifti as text.
    
    Takes the label table from the cifti label map, and writes it to a text
    format matching what is expected by -cifti-label-import.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input cifti label file.
        map_: the number or name of the label map to use.
        table_out: output - the output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelExportTableOutputs`).
    """
    params = cifti_label_export_table_params(
        label_in=label_in,
        map_=map_,
        table_out=table_out,
    )
    return cifti_label_export_table_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_EXPORT_TABLE_METADATA",
    "CiftiLabelExportTableOutputs",
    "cifti_label_export_table",
    "cifti_label_export_table_execute",
    "cifti_label_export_table_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_TO_VERTICES_METADATA = Metadata(
    id="da3e39f9997664c91376607d199e377db4a87475.boutiques",
    name="border-to-vertices",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderToVerticesParameters = typing.TypedDict('BorderToVerticesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-to-vertices"]],
    "surface": InputPathType,
    "border_file": InputPathType,
    "metric_out": str,
    "opt_border_name": typing.NotRequired[str | None],
})
BorderToVerticesParametersTagged = typing.TypedDict('BorderToVerticesParametersTagged', {
    "@type": typing.Literal["workbench/border-to-vertices"],
    "surface": InputPathType,
    "border_file": InputPathType,
    "metric_out": str,
    "opt_border_name": typing.NotRequired[str | None],
})


class BorderToVerticesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderToVerticesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def border_to_vertices_params(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
) -> BorderToVerticesParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-to-vertices",
        "surface": surface,
        "border_file": border_file,
        "metric_out": metric_out,
    }
    if opt_border_name is not None:
        params["opt_border_name"] = opt_border_name
    return params


def border_to_vertices_cargs(
    params: BorderToVerticesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-to-vertices")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("border_file", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_border_name", None) is not None:
        cargs.extend([
            "-border",
            params.get("opt_border_name", None)
        ])
    return cargs


def border_to_vertices_outputs(
    params: BorderToVerticesParameters,
    execution: Execution,
) -> BorderToVerticesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderToVerticesOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def border_to_vertices_execute(
    params: BorderToVerticesParameters,
    runner: Runner | None = None,
) -> BorderToVerticesOutputs:
    """
    border-to-vertices
    
    Draw borders as vertices in a metric file.
    
    Outputs a metric with 1s on vertices that follow a border, and 0s elsewhere.
    By default, a separate metric column is created for each border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToVerticesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_TO_VERTICES_METADATA)
    params = execution.params(params)
    cargs = border_to_vertices_cargs(params, execution)
    ret = border_to_vertices_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_to_vertices(
    surface: InputPathType,
    border_file: InputPathType,
    metric_out: str,
    opt_border_name: str | None = None,
    runner: Runner | None = None,
) -> BorderToVerticesOutputs:
    """
    border-to-vertices
    
    Draw borders as vertices in a metric file.
    
    Outputs a metric with 1s on vertices that follow a border, and 0s elsewhere.
    By default, a separate metric column is created for each border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface the borders are drawn on.
        border_file: the border file.
        metric_out: the output metric file.
        opt_border_name: create ROI for only one border: the name of the border.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderToVerticesOutputs`).
    """
    params = border_to_vertices_params(
        surface=surface,
        border_file=border_file,
        metric_out=metric_out,
        opt_border_name=opt_border_name,
    )
    return border_to_vertices_execute(params, runner)


__all__ = [
    "BORDER_TO_VERTICES_METADATA",
    "BorderToVerticesOutputs",
    "border_to_vertices",
    "border_to_vertices_execute",
    "border_to_vertices_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_MODIFY_KEYS_METADATA = Metadata(
    id="d6011104900b541ac706e3e2a8d7222e98ae764f.boutiques",
    name="label-modify-keys",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelModifyKeysParameters = typing.TypedDict('LabelModifyKeysParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-modify-keys"]],
    "label_in": InputPathType,
    "remap_file": str,
    "label_out": str,
    "opt_column_column": typing.NotRequired[str | None],
})
LabelModifyKeysParametersTagged = typing.TypedDict('LabelModifyKeysParametersTagged', {
    "@type": typing.Literal["workbench/label-modify-keys"],
    "label_in": InputPathType,
    "remap_file": str,
    "label_out": str,
    "opt_column_column": typing.NotRequired[str | None],
})


class LabelModifyKeysOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelModifyKeysParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """output label file"""


def label_modify_keys_params(
    label_in: InputPathType,
    remap_file: str,
    label_out: str,
    opt_column_column: str | None = None,
) -> LabelModifyKeysParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input label file.
        remap_file: text file with old and new key values.
        label_out: output label file.
        opt_column_column: select a single column to use: the column number or\
            name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-modify-keys",
        "label_in": label_in,
        "remap_file": remap_file,
        "label_out": label_out,
    }
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    return params


def label_modify_keys_cargs(
    params: LabelModifyKeysParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-modify-keys")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("remap_file", None))
    cargs.append(params.get("label_out", None))
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    return cargs


def label_modify_keys_outputs(
    params: LabelModifyKeysParameters,
    execution: Execution,
) -> LabelModifyKeysOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelModifyKeysOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
    )
    return ret


def label_modify_keys_execute(
    params: LabelModifyKeysParameters,
    runner: Runner | None = None,
) -> LabelModifyKeysOutputs:
    """
    label-modify-keys
    
    Change key values in a label file.
    
    <remap-file> should have lines of the form 'oldkey newkey', like so:
    
    3 5
    5 8
    8 2
    
    This would change the current label with key '3' to use the key '5' instead,
    5 would use 8, and 8 would use 2. Any collision in key values results in the
    label that was not specified in the remap file getting remapped to an
    otherwise unused key. Remapping more than one key to the same new key, or
    the same key to more than one new key, results in an error. This will not
    change the appearance of the file when displayed, as it will change the key
    values in the data at the same time.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelModifyKeysOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_MODIFY_KEYS_METADATA)
    params = execution.params(params)
    cargs = label_modify_keys_cargs(params, execution)
    ret = label_modify_keys_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_modify_keys(
    label_in: InputPathType,
    remap_file: str,
    label_out: str,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> LabelModifyKeysOutputs:
    """
    label-modify-keys
    
    Change key values in a label file.
    
    <remap-file> should have lines of the form 'oldkey newkey', like so:
    
    3 5
    5 8
    8 2
    
    This would change the current label with key '3' to use the key '5' instead,
    5 would use 8, and 8 would use 2. Any collision in key values results in the
    label that was not specified in the remap file getting remapped to an
    otherwise unused key. Remapping more than one key to the same new key, or
    the same key to more than one new key, results in an error. This will not
    change the appearance of the file when displayed, as it will change the key
    values in the data at the same time.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input label file.
        remap_file: text file with old and new key values.
        label_out: output label file.
        opt_column_column: select a single column to use: the column number or\
            name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelModifyKeysOutputs`).
    """
    params = label_modify_keys_params(
        label_in=label_in,
        remap_file=remap_file,
        label_out=label_out,
        opt_column_column=opt_column_column,
    )
    return label_modify_keys_execute(params, runner)


__all__ = [
    "LABEL_MODIFY_KEYS_METADATA",
    "LabelModifyKeysOutputs",
    "label_modify_keys",
    "label_modify_keys_execute",
    "label_modify_keys_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_PARCEL_RESAMPLING_GENERIC_METADATA = Metadata(
    id="af4253f6abeeb8c49031f8d9530011d0fb4ffa9e.boutiques",
    name="volume-parcel-resampling-generic",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeParcelResamplingGenericParameters = typing.TypedDict('VolumeParcelResamplingGenericParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-parcel-resampling-generic"]],
    "volume_in": InputPathType,
    "cur_parcels": InputPathType,
    "new_parcels": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})
VolumeParcelResamplingGenericParametersTagged = typing.TypedDict('VolumeParcelResamplingGenericParametersTagged', {
    "@type": typing.Literal["workbench/volume-parcel-resampling-generic"],
    "volume_in": InputPathType,
    "cur_parcels": InputPathType,
    "new_parcels": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})


class VolumeParcelResamplingGenericOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeParcelResamplingGenericParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """output volume"""


def volume_parcel_resampling_generic_params(
    volume_in: InputPathType,
    cur_parcels: InputPathType,
    new_parcels: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
) -> VolumeParcelResamplingGenericParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input data volume.
        cur_parcels: label volume of where the parcels currently are.
        new_parcels: label volume of where the parcels should be.
        kernel: gaussian kernel size in mm to smooth by during resampling, as\
            sigma by default.
        volume_out: output volume.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume as input: the subvolume\
            number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-parcel-resampling-generic",
        "volume_in": volume_in,
        "cur_parcels": cur_parcels,
        "new_parcels": new_parcels,
        "kernel": kernel,
        "volume_out": volume_out,
        "opt_fwhm": opt_fwhm,
        "opt_fix_zeros": opt_fix_zeros,
    }
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_parcel_resampling_generic_cargs(
    params: VolumeParcelResamplingGenericParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-parcel-resampling-generic")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(execution.input_file(params.get("cur_parcels", None)))
    cargs.append(execution.input_file(params.get("new_parcels", None)))
    cargs.append(str(params.get("kernel", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    if params.get("opt_fix_zeros", False):
        cargs.append("-fix-zeros")
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    return cargs


def volume_parcel_resampling_generic_outputs(
    params: VolumeParcelResamplingGenericParameters,
    execution: Execution,
) -> VolumeParcelResamplingGenericOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeParcelResamplingGenericOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_parcel_resampling_generic_execute(
    params: VolumeParcelResamplingGenericParameters,
    runner: Runner | None = None,
) -> VolumeParcelResamplingGenericOutputs:
    """
    volume-parcel-resampling-generic
    
    Smooth and resample volume parcels from different volume space.
    
    Smooths and resamples the region inside each label in cur-parcels to the
    region of the same label name in new-parcels. Any voxels in the output label
    region but outside the input label region will be extrapolated from nearby
    data. The -fix-zeros option causes the smoothing to not use an input value
    if it is zero, but still write a smoothed value to the voxel, and after
    smoothing is complete, it will check for any remaining values of zero, and
    fill them in with extrapolated values. The output volume will use the volume
    space of new-parcels, which does not need to be in the same volume space as
    the input.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelResamplingGenericOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_PARCEL_RESAMPLING_GENERIC_METADATA)
    params = execution.params(params)
    cargs = volume_parcel_resampling_generic_cargs(params, execution)
    ret = volume_parcel_resampling_generic_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_parcel_resampling_generic(
    volume_in: InputPathType,
    cur_parcels: InputPathType,
    new_parcels: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeParcelResamplingGenericOutputs:
    """
    volume-parcel-resampling-generic
    
    Smooth and resample volume parcels from different volume space.
    
    Smooths and resamples the region inside each label in cur-parcels to the
    region of the same label name in new-parcels. Any voxels in the output label
    region but outside the input label region will be extrapolated from nearby
    data. The -fix-zeros option causes the smoothing to not use an input value
    if it is zero, but still write a smoothed value to the voxel, and after
    smoothing is complete, it will check for any remaining values of zero, and
    fill them in with extrapolated values. The output volume will use the volume
    space of new-parcels, which does not need to be in the same volume space as
    the input.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input data volume.
        cur_parcels: label volume of where the parcels currently are.
        new_parcels: label volume of where the parcels should be.
        kernel: gaussian kernel size in mm to smooth by during resampling, as\
            sigma by default.
        volume_out: output volume.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume as input: the subvolume\
            number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelResamplingGenericOutputs`).
    """
    params = volume_parcel_resampling_generic_params(
        volume_in=volume_in,
        cur_parcels=cur_parcels,
        new_parcels=new_parcels,
        kernel=kernel,
        volume_out=volume_out,
        opt_fwhm=opt_fwhm,
        opt_fix_zeros=opt_fix_zeros,
        opt_subvolume_subvol=opt_subvolume_subvol,
    )
    return volume_parcel_resampling_generic_execute(params, runner)


__all__ = [
    "VOLUME_PARCEL_RESAMPLING_GENERIC_METADATA",
    "VolumeParcelResamplingGenericOutputs",
    "volume_parcel_resampling_generic",
    "volume_parcel_resampling_generic_execute",
    "volume_parcel_resampling_generic_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ANNOTATION_RESAMPLE_METADATA = Metadata(
    id="d27a061127258ae972e19d738c9377d395c2db20.boutiques",
    name="annotation-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


AnnotationResampleSurfacePairParameters = typing.TypedDict('AnnotationResampleSurfacePairParameters', {
    "@type": typing.NotRequired[typing.Literal["surface_pair"]],
    "source_surface": InputPathType,
    "target_surface": InputPathType,
})
AnnotationResampleSurfacePairParametersTagged = typing.TypedDict('AnnotationResampleSurfacePairParametersTagged', {
    "@type": typing.Literal["surface_pair"],
    "source_surface": InputPathType,
    "target_surface": InputPathType,
})


AnnotationResampleParameters = typing.TypedDict('AnnotationResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/annotation-resample"]],
    "annotation_in": InputPathType,
    "annotation_out": str,
    "surface_pair": typing.NotRequired[list[AnnotationResampleSurfacePairParameters] | None],
})
AnnotationResampleParametersTagged = typing.TypedDict('AnnotationResampleParametersTagged', {
    "@type": typing.Literal["workbench/annotation-resample"],
    "annotation_in": InputPathType,
    "annotation_out": str,
    "surface_pair": typing.NotRequired[list[AnnotationResampleSurfacePairParameters] | None],
})


def annotation_resample_surface_pair_params(
    source_surface: InputPathType,
    target_surface: InputPathType,
) -> AnnotationResampleSurfacePairParametersTagged:
    """
    Build parameters.
    
    Args:
        source_surface: the midthickness surface of the current mesh the\
            annotations use.
        target_surface: the midthickness surface of the mesh the annotations\
            should be transferred to.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surface_pair",
        "source_surface": source_surface,
        "target_surface": target_surface,
    }
    return params


def annotation_resample_surface_pair_cargs(
    params: AnnotationResampleSurfacePairParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surface-pair")
    cargs.append(execution.input_file(params.get("source_surface", None)))
    cargs.append(execution.input_file(params.get("target_surface", None)))
    return cargs


class AnnotationResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `AnnotationResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def annotation_resample_params(
    annotation_in: InputPathType,
    annotation_out: str,
    surface_pair: list[AnnotationResampleSurfacePairParameters] | None = None,
) -> AnnotationResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        annotation_in: the annotation file to resample.
        annotation_out: name of resampled annotation file.
        surface_pair: pair of surfaces for resampling surface annotations for\
            one structure.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/annotation-resample",
        "annotation_in": annotation_in,
        "annotation_out": annotation_out,
    }
    if surface_pair is not None:
        params["surface_pair"] = surface_pair
    return params


def annotation_resample_cargs(
    params: AnnotationResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-annotation-resample")
    cargs.append(execution.input_file(params.get("annotation_in", None)))
    cargs.append(params.get("annotation_out", None))
    if params.get("surface_pair", None) is not None:
        cargs.extend([a for c in [annotation_resample_surface_pair_cargs(s, execution) for s in params.get("surface_pair", None)] for a in c])
    return cargs


def annotation_resample_outputs(
    params: AnnotationResampleParameters,
    execution: Execution,
) -> AnnotationResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AnnotationResampleOutputs(
        root=execution.output_file("."),
    )
    return ret


def annotation_resample_execute(
    params: AnnotationResampleParameters,
    runner: Runner | None = None,
) -> AnnotationResampleOutputs:
    """
    annotation-resample
    
    Resample an annotation file to different meshes.
    
    Resample an annotation file from the source mesh to the target mesh.
    
    Only annotations in surface space are modified, no changes are made to
    annotations in other spaces. The -surface-pair option may be repeated for
    additional structures used by surface space annotations.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnnotationResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANNOTATION_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = annotation_resample_cargs(params, execution)
    ret = annotation_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def annotation_resample(
    annotation_in: InputPathType,
    annotation_out: str,
    surface_pair: list[AnnotationResampleSurfacePairParameters] | None = None,
    runner: Runner | None = None,
) -> AnnotationResampleOutputs:
    """
    annotation-resample
    
    Resample an annotation file to different meshes.
    
    Resample an annotation file from the source mesh to the target mesh.
    
    Only annotations in surface space are modified, no changes are made to
    annotations in other spaces. The -surface-pair option may be repeated for
    additional structures used by surface space annotations.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        annotation_in: the annotation file to resample.
        annotation_out: name of resampled annotation file.
        surface_pair: pair of surfaces for resampling surface annotations for\
            one structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnnotationResampleOutputs`).
    """
    params = annotation_resample_params(
        annotation_in=annotation_in,
        annotation_out=annotation_out,
        surface_pair=surface_pair,
    )
    return annotation_resample_execute(params, runner)


__all__ = [
    "ANNOTATION_RESAMPLE_METADATA",
    "AnnotationResampleOutputs",
    "annotation_resample",
    "annotation_resample_execute",
    "annotation_resample_params",
    "annotation_resample_surface_pair_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_DISTORTION_METADATA = Metadata(
    id="84c6e150f3059b96bf719ca37696b114cc3add00.boutiques",
    name="volume-distortion",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeDistortionParameters = typing.TypedDict('VolumeDistortionParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-distortion"]],
    "warpfield": str,
    "volume_out": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
    "opt_circular": bool,
    "opt_log2": bool,
})
VolumeDistortionParametersTagged = typing.TypedDict('VolumeDistortionParametersTagged', {
    "@type": typing.Literal["workbench/volume-distortion"],
    "warpfield": str,
    "volume_out": str,
    "opt_fnirt_source_volume": typing.NotRequired[str | None],
    "opt_circular": bool,
    "opt_log2": bool,
})


class VolumeDistortionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeDistortionParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output distortion measures"""


def volume_distortion_params(
    warpfield: str,
    volume_out: str,
    opt_fnirt_source_volume: str | None = None,
    opt_circular: bool = False,
    opt_log2: bool = False,
) -> VolumeDistortionParametersTagged:
    """
    Build parameters.
    
    Args:
        warpfield: the warpfield to compute the distortion of.
        volume_out: the output distortion measures.
        opt_fnirt_source_volume: MUST be used if using a fnirt warpfield: the\
            source volume used when generating the warpfield.
        opt_circular: use the circle-based formula for the anisotropic measure.
        opt_log2: apply base-2 log transform.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-distortion",
        "warpfield": warpfield,
        "volume_out": volume_out,
        "opt_circular": opt_circular,
        "opt_log2": opt_log2,
    }
    if opt_fnirt_source_volume is not None:
        params["opt_fnirt_source_volume"] = opt_fnirt_source_volume
    return params


def volume_distortion_cargs(
    params: VolumeDistortionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-distortion")
    cargs.append(params.get("warpfield", None))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_fnirt_source_volume", None) is not None:
        cargs.extend([
            "-fnirt",
            params.get("opt_fnirt_source_volume", None)
        ])
    if params.get("opt_circular", False):
        cargs.append("-circular")
    if params.get("opt_log2", False):
        cargs.append("-log2")
    return cargs


def volume_distortion_outputs(
    params: VolumeDistortionParameters,
    execution: Execution,
) -> VolumeDistortionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeDistortionOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_distortion_execute(
    params: VolumeDistortionParameters,
    runner: Runner | None = None,
) -> VolumeDistortionOutputs:
    """
    volume-distortion
    
    Calculate volume warpfield distortion.
    
    Calculates isotropic and anisotropic distortions in the volume warpfield. At
    each voxel, the gradient of the absolute warpfield is computed to obtain the
    local affine transforms for each voxel (jacobian matrices), and strain
    tensors are derived from them. The isotropic component (volumetric expansion
    ratio) is the product of the three principal strains. The default measure
    ('elongation') for the anisotropic component is the largest principal strain
    divided by the smallest.
    
    The -circular option instead calculates the anisotropic component by
    transforming the principal strains into log space, considering them as
    x-values of points on a circle 120 degrees apart, finds the circle's
    diameter, and transforms that back to a ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeDistortionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_DISTORTION_METADATA)
    params = execution.params(params)
    cargs = volume_distortion_cargs(params, execution)
    ret = volume_distortion_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_distortion(
    warpfield: str,
    volume_out: str,
    opt_fnirt_source_volume: str | None = None,
    opt_circular: bool = False,
    opt_log2: bool = False,
    runner: Runner | None = None,
) -> VolumeDistortionOutputs:
    """
    volume-distortion
    
    Calculate volume warpfield distortion.
    
    Calculates isotropic and anisotropic distortions in the volume warpfield. At
    each voxel, the gradient of the absolute warpfield is computed to obtain the
    local affine transforms for each voxel (jacobian matrices), and strain
    tensors are derived from them. The isotropic component (volumetric expansion
    ratio) is the product of the three principal strains. The default measure
    ('elongation') for the anisotropic component is the largest principal strain
    divided by the smallest.
    
    The -circular option instead calculates the anisotropic component by
    transforming the principal strains into log space, considering them as
    x-values of points on a circle 120 degrees apart, finds the circle's
    diameter, and transforms that back to a ratio.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        warpfield: the warpfield to compute the distortion of.
        volume_out: the output distortion measures.
        opt_fnirt_source_volume: MUST be used if using a fnirt warpfield: the\
            source volume used when generating the warpfield.
        opt_circular: use the circle-based formula for the anisotropic measure.
        opt_log2: apply base-2 log transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeDistortionOutputs`).
    """
    params = volume_distortion_params(
        warpfield=warpfield,
        volume_out=volume_out,
        opt_fnirt_source_volume=opt_fnirt_source_volume,
        opt_circular=opt_circular,
        opt_log2=opt_log2,
    )
    return volume_distortion_execute(params, runner)


__all__ = [
    "VOLUME_DISTORTION_METADATA",
    "VolumeDistortionOutputs",
    "volume_distortion",
    "volume_distortion_execute",
    "volume_distortion_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_FLIP_LR_METADATA = Metadata(
    id="40cffc47a1b0a452d60871c5a8697c2aec5d0f41.boutiques",
    name="surface-flip-lr",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceFlipLrParameters = typing.TypedDict('SurfaceFlipLrParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-flip-lr"]],
    "surface": InputPathType,
    "surface_out": str,
})
SurfaceFlipLrParametersTagged = typing.TypedDict('SurfaceFlipLrParametersTagged', {
    "@type": typing.Literal["workbench/surface-flip-lr"],
    "surface": InputPathType,
    "surface_out": str,
})


class SurfaceFlipLrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceFlipLrParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output flipped surface"""


def surface_flip_lr_params(
    surface: InputPathType,
    surface_out: str,
) -> SurfaceFlipLrParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to flip.
        surface_out: the output flipped surface.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-flip-lr",
        "surface": surface,
        "surface_out": surface_out,
    }
    return params


def surface_flip_lr_cargs(
    params: SurfaceFlipLrParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-flip-lr")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("surface_out", None))
    return cargs


def surface_flip_lr_outputs(
    params: SurfaceFlipLrParameters,
    execution: Execution,
) -> SurfaceFlipLrOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceFlipLrOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_flip_lr_execute(
    params: SurfaceFlipLrParameters,
    runner: Runner | None = None,
) -> SurfaceFlipLrOutputs:
    """
    surface-flip-lr
    
    Mirror a surface through the yz plane.
    
    This command negates the x coordinate of each vertex, and flips the surface
    normals, so that you have a surface of opposite handedness with the same
    features and vertex correspondence, with normals consistent with the
    original surface. That is, if the input surface has normals facing outward,
    the output surface will also have normals facing outward.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipLrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_FLIP_LR_METADATA)
    params = execution.params(params)
    cargs = surface_flip_lr_cargs(params, execution)
    ret = surface_flip_lr_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_flip_lr(
    surface: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceFlipLrOutputs:
    """
    surface-flip-lr
    
    Mirror a surface through the yz plane.
    
    This command negates the x coordinate of each vertex, and flips the surface
    normals, so that you have a surface of opposite handedness with the same
    features and vertex correspondence, with normals consistent with the
    original surface. That is, if the input surface has normals facing outward,
    the output surface will also have normals facing outward.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to flip.
        surface_out: the output flipped surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceFlipLrOutputs`).
    """
    params = surface_flip_lr_params(
        surface=surface,
        surface_out=surface_out,
    )
    return surface_flip_lr_execute(params, runner)


__all__ = [
    "SURFACE_FLIP_LR_METADATA",
    "SurfaceFlipLrOutputs",
    "surface_flip_lr",
    "surface_flip_lr_execute",
    "surface_flip_lr_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_ESTIMATE_FWHM_METADATA = Metadata(
    id="8594e5f631aa822147389c791fdc81f4fc470354.boutiques",
    name="volume-estimate-fwhm",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeEstimateFwhmWholeFileParameters = typing.TypedDict('VolumeEstimateFwhmWholeFileParameters', {
    "@type": typing.NotRequired[typing.Literal["whole_file"]],
    "opt_demean": bool,
})
VolumeEstimateFwhmWholeFileParametersTagged = typing.TypedDict('VolumeEstimateFwhmWholeFileParametersTagged', {
    "@type": typing.Literal["whole_file"],
    "opt_demean": bool,
})


VolumeEstimateFwhmParameters = typing.TypedDict('VolumeEstimateFwhmParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-estimate-fwhm"]],
    "volume": InputPathType,
    "opt_roi_roivol": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "whole_file": typing.NotRequired[VolumeEstimateFwhmWholeFileParameters | None],
})
VolumeEstimateFwhmParametersTagged = typing.TypedDict('VolumeEstimateFwhmParametersTagged', {
    "@type": typing.Literal["workbench/volume-estimate-fwhm"],
    "volume": InputPathType,
    "opt_roi_roivol": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "whole_file": typing.NotRequired[VolumeEstimateFwhmWholeFileParameters | None],
})


def volume_estimate_fwhm_whole_file_params(
    opt_demean: bool = False,
) -> VolumeEstimateFwhmWholeFileParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_demean: subtract the mean image before estimating smoothness.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "whole_file",
        "opt_demean": opt_demean,
    }
    return params


def volume_estimate_fwhm_whole_file_cargs(
    params: VolumeEstimateFwhmWholeFileParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-whole-file")
    if params.get("opt_demean", False):
        cargs.append("-demean")
    return cargs


class VolumeEstimateFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeEstimateFwhmParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_estimate_fwhm_params(
    volume: InputPathType,
    opt_roi_roivol: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    whole_file: VolumeEstimateFwhmWholeFileParameters | None = None,
) -> VolumeEstimateFwhmParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the input volume.
        opt_roi_roivol: use only data within an ROI: the volume to use as an\
            ROI.
        opt_subvolume_subvol: select a single subvolume to estimate smoothness\
            of: the subvolume number or name.
        whole_file: estimate for the whole file at once, not each subvolume\
            separately.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-estimate-fwhm",
        "volume": volume,
    }
    if opt_roi_roivol is not None:
        params["opt_roi_roivol"] = opt_roi_roivol
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    if whole_file is not None:
        params["whole_file"] = whole_file
    return params


def volume_estimate_fwhm_cargs(
    params: VolumeEstimateFwhmParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-estimate-fwhm")
    cargs.append(execution.input_file(params.get("volume", None)))
    if params.get("opt_roi_roivol", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roivol", None))
        ])
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    if params.get("whole_file", None) is not None:
        cargs.extend(volume_estimate_fwhm_whole_file_cargs(params.get("whole_file", None), execution))
    return cargs


def volume_estimate_fwhm_outputs(
    params: VolumeEstimateFwhmParameters,
    execution: Execution,
) -> VolumeEstimateFwhmOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeEstimateFwhmOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_estimate_fwhm_execute(
    params: VolumeEstimateFwhmParameters,
    runner: Runner | None = None,
) -> VolumeEstimateFwhmOutputs:
    """
    volume-estimate-fwhm
    
    Estimate fwhm smoothness of a volume.
    
    Estimates the smoothness of the input volume in X, Y, and Z directions
    separately, printing the estimates to standard output, in mm as FWHM. If
    -subvolume or -whole-file are not specified, each subvolume is estimated and
    displayed separately.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeEstimateFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ESTIMATE_FWHM_METADATA)
    params = execution.params(params)
    cargs = volume_estimate_fwhm_cargs(params, execution)
    ret = volume_estimate_fwhm_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_estimate_fwhm(
    volume: InputPathType,
    opt_roi_roivol: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    whole_file: VolumeEstimateFwhmWholeFileParameters | None = None,
    runner: Runner | None = None,
) -> VolumeEstimateFwhmOutputs:
    """
    volume-estimate-fwhm
    
    Estimate fwhm smoothness of a volume.
    
    Estimates the smoothness of the input volume in X, Y, and Z directions
    separately, printing the estimates to standard output, in mm as FWHM. If
    -subvolume or -whole-file are not specified, each subvolume is estimated and
    displayed separately.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the input volume.
        opt_roi_roivol: use only data within an ROI: the volume to use as an\
            ROI.
        opt_subvolume_subvol: select a single subvolume to estimate smoothness\
            of: the subvolume number or name.
        whole_file: estimate for the whole file at once, not each subvolume\
            separately.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeEstimateFwhmOutputs`).
    """
    params = volume_estimate_fwhm_params(
        volume=volume,
        opt_roi_roivol=opt_roi_roivol,
        opt_subvolume_subvol=opt_subvolume_subvol,
        whole_file=whole_file,
    )
    return volume_estimate_fwhm_execute(params, runner)


__all__ = [
    "VOLUME_ESTIMATE_FWHM_METADATA",
    "VolumeEstimateFwhmOutputs",
    "volume_estimate_fwhm",
    "volume_estimate_fwhm_execute",
    "volume_estimate_fwhm_params",
    "volume_estimate_fwhm_whole_file_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_VECTOR_TOWARD_ROI_METADATA = Metadata(
    id="6787be48822358a7213f746f7be34a018067adb3.boutiques",
    name="metric-vector-toward-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricVectorTowardRoiParameters = typing.TypedDict('MetricVectorTowardRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-vector-toward-roi"]],
    "surface": InputPathType,
    "target_roi": InputPathType,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
})
MetricVectorTowardRoiParametersTagged = typing.TypedDict('MetricVectorTowardRoiParametersTagged', {
    "@type": typing.Literal["workbench/metric-vector-toward-roi"],
    "surface": InputPathType,
    "target_roi": InputPathType,
    "metric_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
})


class MetricVectorTowardRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricVectorTowardRoiParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_vector_toward_roi_params(
    surface: InputPathType,
    target_roi: InputPathType,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
) -> MetricVectorTowardRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute on.
        target_roi: the roi to find the shortest path to.
        metric_out: the output metric.
        opt_roi_roi_metric: don't compute for vertices outside an roi: the\
            region to compute inside, as a metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-vector-toward-roi",
        "surface": surface,
        "target_roi": target_roi,
        "metric_out": metric_out,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    return params


def metric_vector_toward_roi_cargs(
    params: MetricVectorTowardRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-vector-toward-roi")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("target_roi", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    return cargs


def metric_vector_toward_roi_outputs(
    params: MetricVectorTowardRoiParameters,
    execution: Execution,
) -> MetricVectorTowardRoiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricVectorTowardRoiOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_vector_toward_roi_execute(
    params: MetricVectorTowardRoiParameters,
    runner: Runner | None = None,
) -> MetricVectorTowardRoiOutputs:
    """
    metric-vector-toward-roi
    
    Find if vectors point toward an roi.
    
    At each vertex, compute the vector along the start of the shortest path to
    the ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricVectorTowardRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_VECTOR_TOWARD_ROI_METADATA)
    params = execution.params(params)
    cargs = metric_vector_toward_roi_cargs(params, execution)
    ret = metric_vector_toward_roi_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_vector_toward_roi(
    surface: InputPathType,
    target_roi: InputPathType,
    metric_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricVectorTowardRoiOutputs:
    """
    metric-vector-toward-roi
    
    Find if vectors point toward an roi.
    
    At each vertex, compute the vector along the start of the shortest path to
    the ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        target_roi: the roi to find the shortest path to.
        metric_out: the output metric.
        opt_roi_roi_metric: don't compute for vertices outside an roi: the\
            region to compute inside, as a metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricVectorTowardRoiOutputs`).
    """
    params = metric_vector_toward_roi_params(
        surface=surface,
        target_roi=target_roi,
        metric_out=metric_out,
        opt_roi_roi_metric=opt_roi_roi_metric,
    )
    return metric_vector_toward_roi_execute(params, runner)


__all__ = [
    "METRIC_VECTOR_TOWARD_ROI_METADATA",
    "MetricVectorTowardRoiOutputs",
    "metric_vector_toward_roi",
    "metric_vector_toward_roi_execute",
    "metric_vector_toward_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CUT_RESAMPLE_METADATA = Metadata(
    id="3a00cf3f1b235001cfda81c5ab6186879f56a56c.boutiques",
    name="surface-cut-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceCutResampleParameters = typing.TypedDict('SurfaceCutResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-cut-resample"]],
    "surface_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "surface_out": str,
})
SurfaceCutResampleParametersTagged = typing.TypedDict('SurfaceCutResampleParametersTagged', {
    "@type": typing.Literal["workbench/surface-cut-resample"],
    "surface_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "surface_out": str,
})


class SurfaceCutResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceCutResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output surface file"""


def surface_cut_resample_params(
    surface_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    surface_out: str,
) -> SurfaceCutResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_in: the surface file to resample.
        current_sphere: a sphere surface with the mesh that the input surface\
            is currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        surface_out: the output surface file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-cut-resample",
        "surface_in": surface_in,
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
        "surface_out": surface_out,
    }
    return params


def surface_cut_resample_cargs(
    params: SurfaceCutResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-cut-resample")
    cargs.append(execution.input_file(params.get("surface_in", None)))
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    cargs.append(params.get("surface_out", None))
    return cargs


def surface_cut_resample_outputs(
    params: SurfaceCutResampleParameters,
    execution: Execution,
) -> SurfaceCutResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCutResampleOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_cut_resample_execute(
    params: SurfaceCutResampleParameters,
    runner: Runner | None = None,
) -> SurfaceCutResampleOutputs:
    """
    surface-cut-resample
    
    Resample a cut surface.
    
    Resamples a surface file, given two spherical surfaces that are in register.
    Barycentric resampling is used, because it is usually better for resampling
    surfaces, and because it is needed to figure out the new topology anyway.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCutResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CUT_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = surface_cut_resample_cargs(params, execution)
    ret = surface_cut_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_cut_resample(
    surface_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceCutResampleOutputs:
    """
    surface-cut-resample
    
    Resample a cut surface.
    
    Resamples a surface file, given two spherical surfaces that are in register.
    Barycentric resampling is used, because it is usually better for resampling
    surfaces, and because it is needed to figure out the new topology anyway.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_in: the surface file to resample.
        current_sphere: a sphere surface with the mesh that the input surface\
            is currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        surface_out: the output surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCutResampleOutputs`).
    """
    params = surface_cut_resample_params(
        surface_in=surface_in,
        current_sphere=current_sphere,
        new_sphere=new_sphere,
        surface_out=surface_out,
    )
    return surface_cut_resample_execute(params, runner)


__all__ = [
    "SURFACE_CUT_RESAMPLE_METADATA",
    "SurfaceCutResampleOutputs",
    "surface_cut_resample",
    "surface_cut_resample_execute",
    "surface_cut_resample_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_SMOOTHING_METADATA = Metadata(
    id="16d345c3991b1be3c6200b8b8d0e7e17cdd8c48a.boutiques",
    name="volume-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeSmoothingParameters = typing.TypedDict('VolumeSmoothingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-smoothing"]],
    "volume_in": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_roi_roivol": typing.NotRequired[InputPathType | None],
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})
VolumeSmoothingParametersTagged = typing.TypedDict('VolumeSmoothingParametersTagged', {
    "@type": typing.Literal["workbench/volume-smoothing"],
    "volume_in": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_roi_roivol": typing.NotRequired[InputPathType | None],
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})


class VolumeSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeSmoothingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_smoothing_params(
    volume_in: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_roi_roivol: InputPathType | None = None,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
) -> VolumeSmoothingParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the volume to smooth.
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        volume_out: the output volume.
        opt_fwhm: kernel size is FWHM, not sigma.
        opt_roi_roivol: smooth only from data within an ROI: the volume to use\
            as an ROI.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume to smooth: the\
            subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-smoothing",
        "volume_in": volume_in,
        "kernel": kernel,
        "volume_out": volume_out,
        "opt_fwhm": opt_fwhm,
        "opt_fix_zeros": opt_fix_zeros,
    }
    if opt_roi_roivol is not None:
        params["opt_roi_roivol"] = opt_roi_roivol
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_smoothing_cargs(
    params: VolumeSmoothingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-smoothing")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(str(params.get("kernel", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    if params.get("opt_roi_roivol", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roivol", None))
        ])
    if params.get("opt_fix_zeros", False):
        cargs.append("-fix-zeros")
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    return cargs


def volume_smoothing_outputs(
    params: VolumeSmoothingParameters,
    execution: Execution,
) -> VolumeSmoothingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeSmoothingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_smoothing_execute(
    params: VolumeSmoothingParameters,
    runner: Runner | None = None,
) -> VolumeSmoothingOutputs:
    """
    volume-smoothing
    
    Smooth a volume file.
    
    Gaussian smoothing for volumes. By default, smooths all subvolumes with no
    ROI, if ROI is given, only positive voxels in the ROI volume have their
    values used, and all other voxels are set to zero. Smoothing a
    non-orthogonal volume will be significantly slower, because the operation
    cannot be separated into 1-dimensional smoothings without distorting the
    kernel shape.
    
    The -fix-zeros option causes the smoothing to not use an input value if it
    is zero, but still write a smoothed value to the voxel. This is useful for
    zeros that indicate lack of information, preventing them from pulling down
    the intensity of nearby voxels, while giving the zero an extrapolated value.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_SMOOTHING_METADATA)
    params = execution.params(params)
    cargs = volume_smoothing_cargs(params, execution)
    ret = volume_smoothing_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_smoothing(
    volume_in: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_roi_roivol: InputPathType | None = None,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeSmoothingOutputs:
    """
    volume-smoothing
    
    Smooth a volume file.
    
    Gaussian smoothing for volumes. By default, smooths all subvolumes with no
    ROI, if ROI is given, only positive voxels in the ROI volume have their
    values used, and all other voxels are set to zero. Smoothing a
    non-orthogonal volume will be significantly slower, because the operation
    cannot be separated into 1-dimensional smoothings without distorting the
    kernel shape.
    
    The -fix-zeros option causes the smoothing to not use an input value if it
    is zero, but still write a smoothed value to the voxel. This is useful for
    zeros that indicate lack of information, preventing them from pulling down
    the intensity of nearby voxels, while giving the zero an extrapolated value.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the volume to smooth.
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        volume_out: the output volume.
        opt_fwhm: kernel size is FWHM, not sigma.
        opt_roi_roivol: smooth only from data within an ROI: the volume to use\
            as an ROI.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume to smooth: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeSmoothingOutputs`).
    """
    params = volume_smoothing_params(
        volume_in=volume_in,
        kernel=kernel,
        volume_out=volume_out,
        opt_fwhm=opt_fwhm,
        opt_roi_roivol=opt_roi_roivol,
        opt_fix_zeros=opt_fix_zeros,
        opt_subvolume_subvol=opt_subvolume_subvol,
    )
    return volume_smoothing_execute(params, runner)


__all__ = [
    "VOLUME_SMOOTHING_METADATA",
    "VolumeSmoothingOutputs",
    "volume_smoothing",
    "volume_smoothing_execute",
    "volume_smoothing_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_MERGE_METADATA = Metadata(
    id="a4ffb5e806ff58cf992a8408091b306432b7db9b.boutiques",
    name="cifti-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiMergeUpToParameters = typing.TypedDict('CiftiMergeUpToParameters', {
    "@type": typing.NotRequired[typing.Literal["up_to"]],
    "last_index": str,
    "opt_reverse": bool,
})
CiftiMergeUpToParametersTagged = typing.TypedDict('CiftiMergeUpToParametersTagged', {
    "@type": typing.Literal["up_to"],
    "last_index": str,
    "opt_reverse": bool,
})


CiftiMergeIndexParameters = typing.TypedDict('CiftiMergeIndexParameters', {
    "@type": typing.NotRequired[typing.Literal["index"]],
    "index": str,
    "up_to": typing.NotRequired[CiftiMergeUpToParameters | None],
})
CiftiMergeIndexParametersTagged = typing.TypedDict('CiftiMergeIndexParametersTagged', {
    "@type": typing.Literal["index"],
    "index": str,
    "up_to": typing.NotRequired[CiftiMergeUpToParameters | None],
})


CiftiMergeCiftiParameters = typing.TypedDict('CiftiMergeCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti"]],
    "cifti_in": InputPathType,
    "index": typing.NotRequired[list[CiftiMergeIndexParameters] | None],
})
CiftiMergeCiftiParametersTagged = typing.TypedDict('CiftiMergeCiftiParametersTagged', {
    "@type": typing.Literal["cifti"],
    "cifti_in": InputPathType,
    "index": typing.NotRequired[list[CiftiMergeIndexParameters] | None],
})


CiftiMergeParameters = typing.TypedDict('CiftiMergeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-merge"]],
    "cifti_out": str,
    "opt_direction_direction": typing.NotRequired[str | None],
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
    "cifti": typing.NotRequired[list[CiftiMergeCiftiParameters] | None],
})
CiftiMergeParametersTagged = typing.TypedDict('CiftiMergeParametersTagged', {
    "@type": typing.Literal["workbench/cifti-merge"],
    "cifti_out": str,
    "opt_direction_direction": typing.NotRequired[str | None],
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
    "cifti": typing.NotRequired[list[CiftiMergeCiftiParameters] | None],
})


def cifti_merge_up_to_params(
    last_index: str,
    opt_reverse: bool = False,
) -> CiftiMergeUpToParametersTagged:
    """
    Build parameters.
    
    Args:
        last_index: the number or name of the last index to include.
        opt_reverse: use the range in reverse order.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "up_to",
        "last_index": last_index,
        "opt_reverse": opt_reverse,
    }
    return params


def cifti_merge_up_to_cargs(
    params: CiftiMergeUpToParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-up-to")
    cargs.append(params.get("last_index", None))
    if params.get("opt_reverse", False):
        cargs.append("-reverse")
    return cargs


def cifti_merge_index_params(
    index: str,
    up_to: CiftiMergeUpToParameters | None = None,
) -> CiftiMergeIndexParametersTagged:
    """
    Build parameters.
    
    Args:
        index: the index number (starting from 1), or name.
        up_to: use an inclusive range of indices.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "index",
        "index": index,
    }
    if up_to is not None:
        params["up_to"] = up_to
    return params


def cifti_merge_index_cargs(
    params: CiftiMergeIndexParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-index")
    cargs.append(params.get("index", None))
    if params.get("up_to", None) is not None:
        cargs.extend(cifti_merge_up_to_cargs(params.get("up_to", None), execution))
    return cargs


def cifti_merge_cifti_params(
    cifti_in: InputPathType,
    index: list[CiftiMergeIndexParameters] | None = None,
) -> CiftiMergeCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: a cifti file to use data from.
        index: select a single index to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti",
        "cifti_in": cifti_in,
    }
    if index is not None:
        params["index"] = index
    return params


def cifti_merge_cifti_cargs(
    params: CiftiMergeCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    if params.get("index", None) is not None:
        cargs.extend([a for c in [cifti_merge_index_cargs(s, execution) for s in params.get("index", None)] for a in c])
    return cargs


class CiftiMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiMergeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_merge_params(
    cifti_out: str,
    opt_direction_direction: str | None = None,
    opt_mem_limit_limit_gb: float | None = None,
    cifti: list[CiftiMergeCiftiParameters] | None = None,
) -> CiftiMergeParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_out: output cifti file.
        opt_direction_direction: merge in a direction other than along rows:\
            the dimension to split/concatenate along, default ROW.
        opt_mem_limit_limit_gb: restrict memory used for file reading\
            efficiency: memory limit in gigabytes.
        cifti: specify an input cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-merge",
        "cifti_out": cifti_out,
    }
    if opt_direction_direction is not None:
        params["opt_direction_direction"] = opt_direction_direction
    if opt_mem_limit_limit_gb is not None:
        params["opt_mem_limit_limit_gb"] = opt_mem_limit_limit_gb
    if cifti is not None:
        params["cifti"] = cifti
    return params


def cifti_merge_cargs(
    params: CiftiMergeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-merge")
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_direction_direction", None) is not None:
        cargs.extend([
            "-direction",
            params.get("opt_direction_direction", None)
        ])
    if params.get("opt_mem_limit_limit_gb", None) is not None:
        cargs.extend([
            "-mem-limit",
            str(params.get("opt_mem_limit_limit_gb", None))
        ])
    if params.get("cifti", None) is not None:
        cargs.extend([a for c in [cifti_merge_cifti_cargs(s, execution) for s in params.get("cifti", None)] for a in c])
    return cargs


def cifti_merge_outputs(
    params: CiftiMergeParameters,
    execution: Execution,
) -> CiftiMergeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiMergeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_merge_execute(
    params: CiftiMergeParameters,
    runner: Runner | None = None,
) -> CiftiMergeOutputs:
    """
    cifti-merge
    
    Merge or split on series, scalar, or label dimensions.
    
    Given input CIFTI files for which mappings along the selected direction are
    the same type, all either series, scalars, or labels, and the other
    dimensions are index-compatible, this command concatenates the data in the
    specified indices/ranges along the selected direction (by default, on
    typical 2D cifti, concatenate horizontally, so rows become longer). The
    direction can be either an integer starting from 1, or the strings 'ROW' or
    'COLUMN'.
    
    Example: wb_command -cifti-merge out.dtseries.nii -cifti first.dtseries.nii
    -index 1 -cifti second.dtseries.nii
    
    This example would take the first column from first.dtseries.nii, followed
    by all columns from second.dtseries.nii, and write these columns to
    out.dtseries.nii. .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_MERGE_METADATA)
    params = execution.params(params)
    cargs = cifti_merge_cargs(params, execution)
    ret = cifti_merge_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_merge(
    cifti_out: str,
    opt_direction_direction: str | None = None,
    opt_mem_limit_limit_gb: float | None = None,
    cifti: list[CiftiMergeCiftiParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiMergeOutputs:
    """
    cifti-merge
    
    Merge or split on series, scalar, or label dimensions.
    
    Given input CIFTI files for which mappings along the selected direction are
    the same type, all either series, scalars, or labels, and the other
    dimensions are index-compatible, this command concatenates the data in the
    specified indices/ranges along the selected direction (by default, on
    typical 2D cifti, concatenate horizontally, so rows become longer). The
    direction can be either an integer starting from 1, or the strings 'ROW' or
    'COLUMN'.
    
    Example: wb_command -cifti-merge out.dtseries.nii -cifti first.dtseries.nii
    -index 1 -cifti second.dtseries.nii
    
    This example would take the first column from first.dtseries.nii, followed
    by all columns from second.dtseries.nii, and write these columns to
    out.dtseries.nii. .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_out: output cifti file.
        opt_direction_direction: merge in a direction other than along rows:\
            the dimension to split/concatenate along, default ROW.
        opt_mem_limit_limit_gb: restrict memory used for file reading\
            efficiency: memory limit in gigabytes.
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiMergeOutputs`).
    """
    params = cifti_merge_params(
        cifti_out=cifti_out,
        opt_direction_direction=opt_direction_direction,
        opt_mem_limit_limit_gb=opt_mem_limit_limit_gb,
        cifti=cifti,
    )
    return cifti_merge_execute(params, runner)


__all__ = [
    "CIFTI_MERGE_METADATA",
    "CiftiMergeOutputs",
    "cifti_merge",
    "cifti_merge_cifti_params",
    "cifti_merge_execute",
    "cifti_merge_index_params",
    "cifti_merge_params",
    "cifti_merge_up_to_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_VECTOR_OPERATION_METADATA = Metadata(
    id="f2e48c5e90ab1fc3469efcc7e302453fee58fb58.boutiques",
    name="cifti-vector-operation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiVectorOperationParameters = typing.TypedDict('CiftiVectorOperationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-vector-operation"]],
    "vectors_a": InputPathType,
    "vectors_b": InputPathType,
    "operation": str,
    "cifti_out": str,
    "opt_normalize_a": bool,
    "opt_normalize_b": bool,
    "opt_normalize_output": bool,
    "opt_magnitude": bool,
})
CiftiVectorOperationParametersTagged = typing.TypedDict('CiftiVectorOperationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-vector-operation"],
    "vectors_a": InputPathType,
    "vectors_b": InputPathType,
    "operation": str,
    "cifti_out": str,
    "opt_normalize_a": bool,
    "opt_normalize_b": bool,
    "opt_normalize_output": bool,
    "opt_magnitude": bool,
})


class CiftiVectorOperationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiVectorOperationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output file"""


def cifti_vector_operation_params(
    vectors_a: InputPathType,
    vectors_b: InputPathType,
    operation: str,
    cifti_out: str,
    opt_normalize_a: bool = False,
    opt_normalize_b: bool = False,
    opt_normalize_output: bool = False,
    opt_magnitude: bool = False,
) -> CiftiVectorOperationParametersTagged:
    """
    Build parameters.
    
    Args:
        vectors_a: first vector input file.
        vectors_b: second vector input file.
        operation: what vector operation to do.
        cifti_out: the output file.
        opt_normalize_a: normalize vectors of first input.
        opt_normalize_b: normalize vectors of second input.
        opt_normalize_output: normalize output vectors (not valid for dot\
            product).
        opt_magnitude: output the magnitude of the result (not valid for dot\
            product).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-vector-operation",
        "vectors_a": vectors_a,
        "vectors_b": vectors_b,
        "operation": operation,
        "cifti_out": cifti_out,
        "opt_normalize_a": opt_normalize_a,
        "opt_normalize_b": opt_normalize_b,
        "opt_normalize_output": opt_normalize_output,
        "opt_magnitude": opt_magnitude,
    }
    return params


def cifti_vector_operation_cargs(
    params: CiftiVectorOperationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-vector-operation")
    cargs.append(execution.input_file(params.get("vectors_a", None)))
    cargs.append(execution.input_file(params.get("vectors_b", None)))
    cargs.append(params.get("operation", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_normalize_a", False):
        cargs.append("-normalize-a")
    if params.get("opt_normalize_b", False):
        cargs.append("-normalize-b")
    if params.get("opt_normalize_output", False):
        cargs.append("-normalize-output")
    if params.get("opt_magnitude", False):
        cargs.append("-magnitude")
    return cargs


def cifti_vector_operation_outputs(
    params: CiftiVectorOperationParameters,
    execution: Execution,
) -> CiftiVectorOperationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiVectorOperationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_vector_operation_execute(
    params: CiftiVectorOperationParameters,
    runner: Runner | None = None,
) -> CiftiVectorOperationOutputs:
    """
    cifti-vector-operation
    
    Do a vector operation on cifti files.
    
    Does a vector operation on two cifti files (that must have a multiple of 3
    columns). Either of the inputs may have multiple vectors (more than 3
    columns), but not both (at least one must have exactly 3 columns). The
    -magnitude and -normalize-output options may not be specified together, or
    with an operation that returns a scalar (dot product). The <operation>
    parameter must be one of the following:
    
    DOT
    CROSS
    ADD
    SUBTRACT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiVectorOperationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_VECTOR_OPERATION_METADATA)
    params = execution.params(params)
    cargs = cifti_vector_operation_cargs(params, execution)
    ret = cifti_vector_operation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_vector_operation(
    vectors_a: InputPathType,
    vectors_b: InputPathType,
    operation: str,
    cifti_out: str,
    opt_normalize_a: bool = False,
    opt_normalize_b: bool = False,
    opt_normalize_output: bool = False,
    opt_magnitude: bool = False,
    runner: Runner | None = None,
) -> CiftiVectorOperationOutputs:
    """
    cifti-vector-operation
    
    Do a vector operation on cifti files.
    
    Does a vector operation on two cifti files (that must have a multiple of 3
    columns). Either of the inputs may have multiple vectors (more than 3
    columns), but not both (at least one must have exactly 3 columns). The
    -magnitude and -normalize-output options may not be specified together, or
    with an operation that returns a scalar (dot product). The <operation>
    parameter must be one of the following:
    
    DOT
    CROSS
    ADD
    SUBTRACT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        vectors_a: first vector input file.
        vectors_b: second vector input file.
        operation: what vector operation to do.
        cifti_out: the output file.
        opt_normalize_a: normalize vectors of first input.
        opt_normalize_b: normalize vectors of second input.
        opt_normalize_output: normalize output vectors (not valid for dot\
            product).
        opt_magnitude: output the magnitude of the result (not valid for dot\
            product).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiVectorOperationOutputs`).
    """
    params = cifti_vector_operation_params(
        vectors_a=vectors_a,
        vectors_b=vectors_b,
        operation=operation,
        cifti_out=cifti_out,
        opt_normalize_a=opt_normalize_a,
        opt_normalize_b=opt_normalize_b,
        opt_normalize_output=opt_normalize_output,
        opt_magnitude=opt_magnitude,
    )
    return cifti_vector_operation_execute(params, runner)


__all__ = [
    "CIFTI_VECTOR_OPERATION_METADATA",
    "CiftiVectorOperationOutputs",
    "cifti_vector_operation",
    "cifti_vector_operation_execute",
    "cifti_vector_operation_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CREATE_LABEL_METADATA = Metadata(
    id="3a1aca58ce90234c63b19e3c0451b3cb7f90d16b.boutiques",
    name="cifti-create-label",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCreateLabelVolumeParameters = typing.TypedDict('CiftiCreateLabelVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "label_volume": InputPathType,
    "structure_label_volume": InputPathType,
})
CiftiCreateLabelVolumeParametersTagged = typing.TypedDict('CiftiCreateLabelVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "label_volume": InputPathType,
    "structure_label_volume": InputPathType,
})


CiftiCreateLabelLeftLabelParameters = typing.TypedDict('CiftiCreateLabelLeftLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["left_label"]],
    "label": InputPathType,
    "opt_roi_left_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateLabelLeftLabelParametersTagged = typing.TypedDict('CiftiCreateLabelLeftLabelParametersTagged', {
    "@type": typing.Literal["left_label"],
    "label": InputPathType,
    "opt_roi_left_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateLabelRightLabelParameters = typing.TypedDict('CiftiCreateLabelRightLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["right_label"]],
    "label": InputPathType,
    "opt_roi_right_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateLabelRightLabelParametersTagged = typing.TypedDict('CiftiCreateLabelRightLabelParametersTagged', {
    "@type": typing.Literal["right_label"],
    "label": InputPathType,
    "opt_roi_right_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateLabelCerebellumLabelParameters = typing.TypedDict('CiftiCreateLabelCerebellumLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["cerebellum_label"]],
    "label": InputPathType,
    "opt_roi_cerebellum_roi_metric": typing.NotRequired[InputPathType | None],
})
CiftiCreateLabelCerebellumLabelParametersTagged = typing.TypedDict('CiftiCreateLabelCerebellumLabelParametersTagged', {
    "@type": typing.Literal["cerebellum_label"],
    "label": InputPathType,
    "opt_roi_cerebellum_roi_metric": typing.NotRequired[InputPathType | None],
})


CiftiCreateLabelParameters = typing.TypedDict('CiftiCreateLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-create-label"]],
    "cifti_out": str,
    "volume": typing.NotRequired[CiftiCreateLabelVolumeParameters | None],
    "left_label": typing.NotRequired[CiftiCreateLabelLeftLabelParameters | None],
    "right_label": typing.NotRequired[CiftiCreateLabelRightLabelParameters | None],
    "cerebellum_label": typing.NotRequired[CiftiCreateLabelCerebellumLabelParameters | None],
})
CiftiCreateLabelParametersTagged = typing.TypedDict('CiftiCreateLabelParametersTagged', {
    "@type": typing.Literal["workbench/cifti-create-label"],
    "cifti_out": str,
    "volume": typing.NotRequired[CiftiCreateLabelVolumeParameters | None],
    "left_label": typing.NotRequired[CiftiCreateLabelLeftLabelParameters | None],
    "right_label": typing.NotRequired[CiftiCreateLabelRightLabelParameters | None],
    "cerebellum_label": typing.NotRequired[CiftiCreateLabelCerebellumLabelParameters | None],
})


def cifti_create_label_volume_params(
    label_volume: InputPathType,
    structure_label_volume: InputPathType,
) -> CiftiCreateLabelVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        label_volume: label volume file containing the data to be copied.
        structure_label_volume: label volume file that defines which voxels to\
            use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "label_volume": label_volume,
        "structure_label_volume": structure_label_volume,
    }
    return params


def cifti_create_label_volume_cargs(
    params: CiftiCreateLabelVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(execution.input_file(params.get("label_volume", None)))
    cargs.append(execution.input_file(params.get("structure_label_volume", None)))
    return cargs


def cifti_create_label_left_label_params(
    label: InputPathType,
    opt_roi_left_roi_metric: InputPathType | None = None,
) -> CiftiCreateLabelLeftLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the label file.
        opt_roi_left_roi_metric: roi of vertices to use from left surface: the\
            ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "left_label",
        "label": label,
    }
    if opt_roi_left_roi_metric is not None:
        params["opt_roi_left_roi_metric"] = opt_roi_left_roi_metric
    return params


def cifti_create_label_left_label_cargs(
    params: CiftiCreateLabelLeftLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-left-label")
    cargs.append(execution.input_file(params.get("label", None)))
    if params.get("opt_roi_left_roi_metric", None) is not None:
        cargs.extend([
            "-roi-left",
            execution.input_file(params.get("opt_roi_left_roi_metric", None))
        ])
    return cargs


def cifti_create_label_right_label_params(
    label: InputPathType,
    opt_roi_right_roi_metric: InputPathType | None = None,
) -> CiftiCreateLabelRightLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the label file.
        opt_roi_right_roi_metric: roi of vertices to use from right surface:\
            the ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "right_label",
        "label": label,
    }
    if opt_roi_right_roi_metric is not None:
        params["opt_roi_right_roi_metric"] = opt_roi_right_roi_metric
    return params


def cifti_create_label_right_label_cargs(
    params: CiftiCreateLabelRightLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-right-label")
    cargs.append(execution.input_file(params.get("label", None)))
    if params.get("opt_roi_right_roi_metric", None) is not None:
        cargs.extend([
            "-roi-right",
            execution.input_file(params.get("opt_roi_right_roi_metric", None))
        ])
    return cargs


def cifti_create_label_cerebellum_label_params(
    label: InputPathType,
    opt_roi_cerebellum_roi_metric: InputPathType | None = None,
) -> CiftiCreateLabelCerebellumLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        label: the label file.
        opt_roi_cerebellum_roi_metric: roi of vertices to use from right\
            surface: the ROI as a metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cerebellum_label",
        "label": label,
    }
    if opt_roi_cerebellum_roi_metric is not None:
        params["opt_roi_cerebellum_roi_metric"] = opt_roi_cerebellum_roi_metric
    return params


def cifti_create_label_cerebellum_label_cargs(
    params: CiftiCreateLabelCerebellumLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cerebellum-label")
    cargs.append(execution.input_file(params.get("label", None)))
    if params.get("opt_roi_cerebellum_roi_metric", None) is not None:
        cargs.extend([
            "-roi-cerebellum",
            execution.input_file(params.get("opt_roi_cerebellum_roi_metric", None))
        ])
    return cargs


class CiftiCreateLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCreateLabelParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_label_params(
    cifti_out: str,
    volume: CiftiCreateLabelVolumeParameters | None = None,
    left_label: CiftiCreateLabelLeftLabelParameters | None = None,
    right_label: CiftiCreateLabelRightLabelParameters | None = None,
    cerebellum_label: CiftiCreateLabelCerebellumLabelParameters | None = None,
) -> CiftiCreateLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_out: the output cifti file.
        volume: volume component.
        left_label: label file for left surface.
        right_label: label for left surface.
        cerebellum_label: label for the cerebellum.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-create-label",
        "cifti_out": cifti_out,
    }
    if volume is not None:
        params["volume"] = volume
    if left_label is not None:
        params["left_label"] = left_label
    if right_label is not None:
        params["right_label"] = right_label
    if cerebellum_label is not None:
        params["cerebellum_label"] = cerebellum_label
    return params


def cifti_create_label_cargs(
    params: CiftiCreateLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-label")
    cargs.append(params.get("cifti_out", None))
    if params.get("volume", None) is not None:
        cargs.extend(cifti_create_label_volume_cargs(params.get("volume", None), execution))
    if params.get("left_label", None) is not None:
        cargs.extend(cifti_create_label_left_label_cargs(params.get("left_label", None), execution))
    if params.get("right_label", None) is not None:
        cargs.extend(cifti_create_label_right_label_cargs(params.get("right_label", None), execution))
    if params.get("cerebellum_label", None) is not None:
        cargs.extend(cifti_create_label_cerebellum_label_cargs(params.get("cerebellum_label", None), execution))
    return cargs


def cifti_create_label_outputs(
    params: CiftiCreateLabelParameters,
    execution: Execution,
) -> CiftiCreateLabelOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCreateLabelOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_create_label_execute(
    params: CiftiCreateLabelParameters,
    runner: Runner | None = None,
) -> CiftiCreateLabelOutputs:
    """
    cifti-create-label
    
    Create a cifti label file.
    
    All input files must have the same number of columns/subvolumes. Only the
    specified components will be in the output cifti. At least one component
    must be specified.
    
    The -volume option requires two volume arguments, the label-volume argument
    contains all labels you want to display (e.g. nuclei of the thalamus),
    whereas the structure-label-volume argument contains all CIFTI voxel-based
    structures you want to include data within (e.g. THALAMUS_LEFT,
    THALAMUS_RIGHT, etc). See -volume-label-import and -volume-help for format
    details of label volume files. If you just want the labels in voxels to be
    the structure names, you may use the same file for both arguments. The
    structure-label-volume must use some of the label names from this list, all
    other label names in the structure-label-volume will be ignored:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_LABEL_METADATA)
    params = execution.params(params)
    cargs = cifti_create_label_cargs(params, execution)
    ret = cifti_create_label_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_create_label(
    cifti_out: str,
    volume: CiftiCreateLabelVolumeParameters | None = None,
    left_label: CiftiCreateLabelLeftLabelParameters | None = None,
    right_label: CiftiCreateLabelRightLabelParameters | None = None,
    cerebellum_label: CiftiCreateLabelCerebellumLabelParameters | None = None,
    runner: Runner | None = None,
) -> CiftiCreateLabelOutputs:
    """
    cifti-create-label
    
    Create a cifti label file.
    
    All input files must have the same number of columns/subvolumes. Only the
    specified components will be in the output cifti. At least one component
    must be specified.
    
    The -volume option requires two volume arguments, the label-volume argument
    contains all labels you want to display (e.g. nuclei of the thalamus),
    whereas the structure-label-volume argument contains all CIFTI voxel-based
    structures you want to include data within (e.g. THALAMUS_LEFT,
    THALAMUS_RIGHT, etc). See -volume-label-import and -volume-help for format
    details of label volume files. If you just want the labels in voxels to be
    the structure names, you may use the same file for both arguments. The
    structure-label-volume must use some of the label names from this list, all
    other label names in the structure-label-volume will be ignored:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_out: the output cifti file.
        volume: volume component.
        left_label: label file for left surface.
        right_label: label for left surface.
        cerebellum_label: label for the cerebellum.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateLabelOutputs`).
    """
    params = cifti_create_label_params(
        cifti_out=cifti_out,
        volume=volume,
        left_label=left_label,
        right_label=right_label,
        cerebellum_label=cerebellum_label,
    )
    return cifti_create_label_execute(params, runner)


__all__ = [
    "CIFTI_CREATE_LABEL_METADATA",
    "CiftiCreateLabelOutputs",
    "cifti_create_label",
    "cifti_create_label_cerebellum_label_params",
    "cifti_create_label_execute",
    "cifti_create_label_left_label_params",
    "cifti_create_label_params",
    "cifti_create_label_right_label_params",
    "cifti_create_label_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_ADJACENCY_METADATA = Metadata(
    id="bcb2ac9510f2329e36c8dab72f902febc2c62123.boutiques",
    name="cifti-label-adjacency",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelAdjacencyParameters = typing.TypedDict('CiftiLabelAdjacencyParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-adjacency"]],
    "label_in": InputPathType,
    "adjacency_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
})
CiftiLabelAdjacencyParametersTagged = typing.TypedDict('CiftiLabelAdjacencyParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-adjacency"],
    "label_in": InputPathType,
    "adjacency_out": str,
    "opt_left_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_right_surface_surface": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_surface_surface": typing.NotRequired[InputPathType | None],
})


class CiftiLabelAdjacencyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelAdjacencyParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    adjacency_out: OutputPathType
    """the output cifti pconn adjacency matrix"""


def cifti_label_adjacency_params(
    label_in: InputPathType,
    adjacency_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
) -> CiftiLabelAdjacencyParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input cifti label file.
        adjacency_out: the output cifti pconn adjacency matrix.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-adjacency",
        "label_in": label_in,
        "adjacency_out": adjacency_out,
    }
    if opt_left_surface_surface is not None:
        params["opt_left_surface_surface"] = opt_left_surface_surface
    if opt_right_surface_surface is not None:
        params["opt_right_surface_surface"] = opt_right_surface_surface
    if opt_cerebellum_surface_surface is not None:
        params["opt_cerebellum_surface_surface"] = opt_cerebellum_surface_surface
    return params


def cifti_label_adjacency_cargs(
    params: CiftiLabelAdjacencyParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-adjacency")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("adjacency_out", None))
    if params.get("opt_left_surface_surface", None) is not None:
        cargs.extend([
            "-left-surface",
            execution.input_file(params.get("opt_left_surface_surface", None))
        ])
    if params.get("opt_right_surface_surface", None) is not None:
        cargs.extend([
            "-right-surface",
            execution.input_file(params.get("opt_right_surface_surface", None))
        ])
    if params.get("opt_cerebellum_surface_surface", None) is not None:
        cargs.extend([
            "-cerebellum-surface",
            execution.input_file(params.get("opt_cerebellum_surface_surface", None))
        ])
    return cargs


def cifti_label_adjacency_outputs(
    params: CiftiLabelAdjacencyParameters,
    execution: Execution,
) -> CiftiLabelAdjacencyOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelAdjacencyOutputs(
        root=execution.output_file("."),
        adjacency_out=execution.output_file(params.get("adjacency_out", None)),
    )
    return ret


def cifti_label_adjacency_execute(
    params: CiftiLabelAdjacencyParameters,
    runner: Runner | None = None,
) -> CiftiLabelAdjacencyOutputs:
    """
    cifti-label-adjacency
    
    Make adjacency matrix of a cifti label file.
    
    Find face-adjacent voxels and connected vertices that have different label
    values, and count them for each pair. Put the resulting counts into a
    parcellated connectivity file, with the diagonal being zero. This gives a
    rough estimate of how long or expansive the border between two labels is.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelAdjacencyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_ADJACENCY_METADATA)
    params = execution.params(params)
    cargs = cifti_label_adjacency_cargs(params, execution)
    ret = cifti_label_adjacency_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_adjacency(
    label_in: InputPathType,
    adjacency_out: str,
    opt_left_surface_surface: InputPathType | None = None,
    opt_right_surface_surface: InputPathType | None = None,
    opt_cerebellum_surface_surface: InputPathType | None = None,
    runner: Runner | None = None,
) -> CiftiLabelAdjacencyOutputs:
    """
    cifti-label-adjacency
    
    Make adjacency matrix of a cifti label file.
    
    Find face-adjacent voxels and connected vertices that have different label
    values, and count them for each pair. Put the resulting counts into a
    parcellated connectivity file, with the diagonal being zero. This gives a
    rough estimate of how long or expansive the border between two labels is.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input cifti label file.
        adjacency_out: the output cifti pconn adjacency matrix.
        opt_left_surface_surface: specify the left surface to use: the left\
            surface file.
        opt_right_surface_surface: specify the right surface to use: the right\
            surface file.
        opt_cerebellum_surface_surface: specify the cerebellum surface to use:\
            the cerebellum surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelAdjacencyOutputs`).
    """
    params = cifti_label_adjacency_params(
        label_in=label_in,
        adjacency_out=adjacency_out,
        opt_left_surface_surface=opt_left_surface_surface,
        opt_right_surface_surface=opt_right_surface_surface,
        opt_cerebellum_surface_surface=opt_cerebellum_surface_surface,
    )
    return cifti_label_adjacency_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_ADJACENCY_METADATA",
    "CiftiLabelAdjacencyOutputs",
    "cifti_label_adjacency",
    "cifti_label_adjacency_execute",
    "cifti_label_adjacency_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CLOSEST_VERTEX_METADATA = Metadata(
    id="1424c0e261ad28fcc53735d9c94a66297aa77546.boutiques",
    name="surface-closest-vertex",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceClosestVertexParameters = typing.TypedDict('SurfaceClosestVertexParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-closest-vertex"]],
    "surface": InputPathType,
    "coord_list_file": str,
    "vertex_list_out": str,
})
SurfaceClosestVertexParametersTagged = typing.TypedDict('SurfaceClosestVertexParametersTagged', {
    "@type": typing.Literal["workbench/surface-closest-vertex"],
    "surface": InputPathType,
    "coord_list_file": str,
    "vertex_list_out": str,
})


class SurfaceClosestVertexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceClosestVertexParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_closest_vertex_params(
    surface: InputPathType,
    coord_list_file: str,
    vertex_list_out: str,
) -> SurfaceClosestVertexParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use.
        coord_list_file: text file with coordinates.
        vertex_list_out: output - the output text file with vertex numbers.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-closest-vertex",
        "surface": surface,
        "coord_list_file": coord_list_file,
        "vertex_list_out": vertex_list_out,
    }
    return params


def surface_closest_vertex_cargs(
    params: SurfaceClosestVertexParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-closest-vertex")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("coord_list_file", None))
    cargs.append(params.get("vertex_list_out", None))
    return cargs


def surface_closest_vertex_outputs(
    params: SurfaceClosestVertexParameters,
    execution: Execution,
) -> SurfaceClosestVertexOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceClosestVertexOutputs(
        root=execution.output_file("."),
    )
    return ret


def surface_closest_vertex_execute(
    params: SurfaceClosestVertexParameters,
    runner: Runner | None = None,
) -> SurfaceClosestVertexOutputs:
    """
    surface-closest-vertex
    
    Find closest surface vertex to coordinates.
    
    For each coordinate XYZ triple, find the closest vertex in the surface, and
    output its vertex number into a text file. The input file should only use
    whitespace to separate coordinates (spaces, newlines, tabs), for instance:
    
    20 30 25
    30 -20 10.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceClosestVertexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CLOSEST_VERTEX_METADATA)
    params = execution.params(params)
    cargs = surface_closest_vertex_cargs(params, execution)
    ret = surface_closest_vertex_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_closest_vertex(
    surface: InputPathType,
    coord_list_file: str,
    vertex_list_out: str,
    runner: Runner | None = None,
) -> SurfaceClosestVertexOutputs:
    """
    surface-closest-vertex
    
    Find closest surface vertex to coordinates.
    
    For each coordinate XYZ triple, find the closest vertex in the surface, and
    output its vertex number into a text file. The input file should only use
    whitespace to separate coordinates (spaces, newlines, tabs), for instance:
    
    20 30 25
    30 -20 10.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use.
        coord_list_file: text file with coordinates.
        vertex_list_out: output - the output text file with vertex numbers.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceClosestVertexOutputs`).
    """
    params = surface_closest_vertex_params(
        surface=surface,
        coord_list_file=coord_list_file,
        vertex_list_out=vertex_list_out,
    )
    return surface_closest_vertex_execute(params, runner)


__all__ = [
    "SURFACE_CLOSEST_VERTEX_METADATA",
    "SurfaceClosestVertexOutputs",
    "surface_closest_vertex",
    "surface_closest_vertex_execute",
    "surface_closest_vertex_params",
]
